@@ -68,11 +68,11 @@ fi
 
 #ICONS=/usr/share/icons/antix-moka
 #ICONS=/usr/share/icons/antix-faenza
-#ICONS=/usr/share/icons/antix-papirus
+ICONS=/usr/share/icons/antix-papirus
 #ICONS=/usr/share/icons/antix-numix-bevel
 #ICONS=/usr/share/icons/antix-numix-square
 #ICONS=/usr/share/icons/antix-kora
-ICONS=/usr/share/icons/antix-qogir
+#ICONS=/usr/share/icons/antix-qogir
 ICONS2=/usr/share/pixmaps
 ICONS3=/usr/share/icons/papirus-antix/48x48/apps
 
